
#include "external_interface/external_interface.h"
#include "external_interface/external_interface_testing.h"

typedef wiselib::OSMODEL Os;

typedef Os::Debug Debug;
#ifdef SHAWN
	#include "external_interface/shawn/shawn_stringtag_debug.h"
	#include "external_interface/shawn/shawn_tagid_radio.h"
	#include "external_interface/shawn/shawn_tag_neighborhood.h"

	typedef wiselib::ShawnStringTagDebugModel<Os> LabelDebug;
	typedef wiselib::ShawnTagIdRadio<Os> Radio;
	typedef wiselib::ShawnTagNeighborhood<Os, Radio> Neighborhood;
#else
	typedef Os::Debug LabelDebug;
	typedef Os::Radio Radio;
#endif
	
#include "cole_vishkin.h"
typedef ColeVishkin<Os, Radio, Neighborhood, Debug, LabelDebug> cole_vishkin_t;
	

class ColeVishkinApp {
	public:
		void init(Os::AppMainParameter& amp) {
			radio_ = &wiselib::FacetProvider<Os, Radio>::get_facet(amp);
			debug_ = &wiselib::FacetProvider<Os, Debug>::get_facet(amp);
			labeldebug_ = &wiselib::FacetProvider<Os, LabelDebug>::get_facet(amp);
			
			radio_->enable_radio();
			
			neighborhood_.init(radio_);
			
			cole_vishkin_.init(radio_, &neighborhood_, debug_, labeldebug_);
		}
		
	private:
		Radio::self_pointer_t radio_;
		Debug::self_pointer_t debug_;
		LabelDebug::self_pointer_t labeldebug_;
		Neighborhood neighborhood_;
		cole_vishkin_t cole_vishkin_;
};


wiselib::WiselibApplication<Os, ColeVishkinApp> app;
void application_main(Os::AppMainParameter& amp) {
	app.init(amp);
}

